@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2002-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2002-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 // own header
@@ -9,13 +9,12 @@
 //// local includes
 #include "optionstate.h"
 #include "umbrellosettings.h"
-
+// #include "dialog_utils.h"
 #include "selectlayouttypewidget.h"
 
 //// kde includes
 #include <KLocalizedString>
 #include <KColorButton>
-#include <KIntSpinBox>
 
 //// qt includes
 #include <QCheckBox>
@@ -24,11 +23,7 @@
 #include <QGroupBox>
 #include <QLabel>
 #include <QVBoxLayout>
-
-//TODO don't do that, but it's better than hardcoded in the functions body
-#define FILL_COLOR QColor(255, 255, 192)
-#define LINK_COLOR Qt::red
-#define TEXT_COLOR Qt::black
+#include <QSpinBox>
 
 /**
  * Constructor - observe and modify an OptionState structure
@@ -58,7 +53,7 @@ void UIOptionsPage::setupPage()
     QVBoxLayout* uiPageLayout = new QVBoxLayout(this);
     QGroupBox *box = new QGroupBox(i18nc("General options", "General"), this);
     QGridLayout * otherLayout = new QGridLayout(box);
-    //otherLayout->setSpacing(spacingHint());
+    //otherLayout->setSpacing(Dialog_Utils::spacingHint());
     otherLayout->setMargin(fontMetrics().height());
     uiPageLayout->addWidget(box);
 
@@ -71,10 +66,6 @@ void UIOptionsPage::setupPage()
     layoutAssocs->setMargin(fontMetrics().height());
     uiPageLayout->addWidget(boxAssocs);
 
-    m_angularLinesCB = new QCheckBox(i18n("Use angular association lines"), boxAssocs);
-    m_angularLinesCB->setChecked(m_options->generalState.angularlines);
-    layoutAssocs->addWidget(m_angularLinesCB, 0, 0);
-
     m_layoutTypeW = new SelectLayoutTypeWidget(i18n("Create new association lines as:"), Settings::optionState().generalState.layoutType, boxAssocs);
     m_layoutTypeW->addToLayout(layoutAssocs, 1);
 
@@ -124,15 +115,11 @@ void UIOptionsPage::setupPage()
     m_lineWidthCB = new QCheckBox(i18n("Custom line width"), m_colorGB);
     colorLayout->addWidget(m_lineWidthCB, 5, 0);
 
-#if QT_VERSION >= 0x050000
     m_lineWidthB = new QSpinBox(m_colorGB);
     m_lineWidthB->setMinimum(0);
     m_lineWidthB->setMaximum(10);
     m_lineWidthB->setSingleStep(1);
     m_lineWidthB->setValue(m_options->uiState.lineWidth);
-#else
-    m_lineWidthB = new KIntSpinBox(0, 10, 1, m_options->uiState.lineWidth, m_colorGB);
-#endif
     colorLayout->addWidget(m_lineWidthB, 5, 1);
 
     m_useFillColorCB = new QCheckBox(i18n("&Use fill color"), m_colorGB);
@@ -174,7 +161,6 @@ void UIOptionsPage::setDefaults()
     slotLineWidthCBChecked(false);
     m_rightToLeftUI->setChecked(false);
     m_layoutTypeW->setCurrentLayout(Uml::LayoutType::Direct);
-    m_angularLinesCB->setChecked(false);
 }
 
 /**
@@ -190,7 +176,6 @@ void UIOptionsPage::apply()
     m_options->uiState.backgroundColor = m_bgColorB->color();
     m_options->uiState.gridDotColor = m_gridColorB->color();
     m_options->generalState.layoutType = m_layoutTypeW->currentLayout();
-    m_options->generalState.angularlines = m_angularLinesCB->isChecked();
     UmbrelloSettings::setRightToLeftUI(m_rightToLeftUI->isChecked());
     qApp->setLayoutDirection(UmbrelloSettings::rightToLeftUI() ? Qt::RightToLeft : Qt::LeftToRight);
 }
@@ -198,7 +183,7 @@ void UIOptionsPage::apply()
 void UIOptionsPage::slotTextCBChecked(bool value)
 {
     if (value == false) {
-        m_textColorB->setColor(TEXT_COLOR);
+        m_textColorB->setColor(m_options->uiState.textColor);
         m_textColorB->setDisabled(true);
     }
     else {
@@ -209,7 +194,7 @@ void UIOptionsPage::slotTextCBChecked(bool value)
 void UIOptionsPage::slotLineCBChecked(bool value)
 {
     if (value == false) {
-        m_lineColorB->setColor(LINK_COLOR);
+        m_lineColorB->setColor(m_options->uiState.lineColor);
         m_lineColorB->setDisabled(true);
     }
     else {
@@ -220,7 +205,7 @@ void UIOptionsPage::slotLineCBChecked(bool value)
 void UIOptionsPage::slotFillCBChecked(bool value)
 {
     if (value == false) {
-        m_fillColorB->setColor(FILL_COLOR);
+        m_fillColorB->setColor(m_options->uiState.fillColor);
         m_fillColorB->setDisabled(true);
     }
     else {
