@@ -23,7 +23,7 @@ class QRadioButton;
 class QPushButton;
 class QCheckBox;
 class QToolButton;
-class KLineEdit;
+class QLineEdit;
 class UMLDoc;
 class UMLObject;
 class UMLOperation;
@@ -69,8 +69,8 @@ protected:
     QLabel*               m_pTagL[N_STEREOATTRS];
     UMLDatatypeWidget*    m_datatypeWidget;
     UMLStereotypeWidget*  m_stereotypeWidget;
-    KLineEdit*            m_pNameLE;
-    KLineEdit*            m_pTagLE[N_STEREOATTRS];
+    QLineEdit*            m_pNameLE;
+    QLineEdit*            m_pTagLE[N_STEREOATTRS];
     QCheckBox*            m_pAbstractCB;
     QCheckBox*            m_pStaticCB;
     QCheckBox*            m_pQueryCB;
