@@ -8,7 +8,7 @@
 #include "associationline.h"
 #include "associationwidget.h"
 #include "cmds.h"
-#define DBG_SRC QLatin1String("LayoutGenerator")
+#define DBG_SRC QStringLiteral("LayoutGenerator")
 #include "debug_utils.h"
 #include "floatingtextwidget.h"
 #include "uml.h"
@@ -18,9 +18,6 @@
 #include <KConfigGroup>
 #include <KDesktopFile>
 #include <KLocalizedString>
-#if QT_VERSION < 0x050000
-#include <KStandardDirs>
-#endif
 
 // qt includes
 #include <QDir>
@@ -28,9 +25,7 @@
 #include <QHash>
 #include <QProcess>
 #include <QRegExp>
-#if QT_VERSION >= 0x050000
 #include <QStandardPaths>
-#endif
 #include <QString>
 #include <QTemporaryFile>
 //#include <QTextStream>
@@ -49,12 +44,12 @@
 static QString pngViewer()
 {
 #ifdef Q_OS_WIN
-    return QLatin1String("start");
+    return QStringLiteral("start");
 #else
 #ifdef Q_OS_MAC
-    return QLatin1String("unknown");
+    return QStringLiteral("unknown");
 #else
-    return QLatin1String("okular");
+    return QStringLiteral("okular");
 #endif
 #endif
 }
@@ -62,12 +57,12 @@ static QString pngViewer()
 static QString textViewer()
 {
 #ifdef Q_OS_WIN
-    return QLatin1String("start");
+    return QStringLiteral("start");
 #else
 #ifdef Q_OS_MAC
-    return QLatin1String("unknown");
+    return QStringLiteral("unknown");
 #else
-    return QLatin1String("mcedit");
+    return QStringLiteral("mcedit");
 #endif
 #endif
 }
@@ -150,23 +145,23 @@ bool LayoutGenerator::generate(UMLScene *scene, const QString &variant)
 
     QProcess p;
     QStringList args;
-    args << QLatin1String("-o") << out.fileName() << QLatin1String("-Tplain-ext") << in.fileName();
+    args << QStringLiteral("-o") << out.fileName() << QStringLiteral("-Tplain-ext") << in.fileName();
     p.start(executable, args);
     p.waitForFinished();
 
     args.clear();
-    args << QLatin1String("-o") << xdotOut.fileName() << QLatin1String("-Txdot") << in.fileName();
+    args << QStringLiteral("-o") << xdotOut.fileName() << QStringLiteral("-Txdot") << in.fileName();
     p.start(executable, args);
     p.waitForFinished();
 
 #ifdef LAYOUTGENERATOR_DEBUG
     QTemporaryFile pngFile;
     pngFile.setAutoRemove(false);
-    pngFile.setFileTemplate(QDir::tempPath() + QLatin1String("/umbrello-layoutgenerator-XXXXXX.png"));
+    pngFile.setFileTemplate(QDir::tempPath() + QStringLiteral("/umbrello-layoutgenerator-XXXXXX.png"));
     pngFile.open();
     pngFile.close();
     args.clear();
-    args << QLatin1String("-o") << pngFile.fileName() << QLatin1String("-Tpng") << in.fileName();
+    args << QStringLiteral("-o") << pngFile.fileName() << QStringLiteral("-Tpng") << in.fileName();
     p.start(executable, args);
     p.waitForFinished();
     qDebug() << pngViewer() << pngFile.fileName();
@@ -196,10 +191,10 @@ bool LayoutGenerator::apply(UMLScene *scene)
     foreach(AssociationWidget *assoc, scene->associationList()) {
         AssociationLine& path = assoc->associationLine();
         QString type = Uml::AssociationType::toString(assoc->associationType()).toLower();
-        QString key = QLatin1String("type::") + type;
+        QString key = QStringLiteral("type::") + type;
 
         QString id;
-        if (m_edgeParameters.contains(QLatin1String("id::") + key) && m_edgeParameters[QLatin1String("id::") + key] == QLatin1String("swap"))
+        if (m_edgeParameters.contains(QStringLiteral("id::") + key) && m_edgeParameters[QStringLiteral("id::") + key] == QStringLiteral("swap"))
             id = fixID(Uml::ID::toString(assoc->widgetLocalIDForRole(Uml::RoleType::A)) + Uml::ID::toString(assoc->widgetLocalIDForRole(Uml::RoleType::B)));
         else
             id = fixID(Uml::ID::toString(assoc->widgetLocalIDForRole(Uml::RoleType::B)) + Uml::ID::toString(assoc->widgetLocalIDForRole(Uml::RoleType::A)));
@@ -306,8 +301,7 @@ bool LayoutGenerator::apply(UMLScene *scene)
 bool LayoutGenerator::availableConfigFiles(UMLScene *scene, QHash<QString,QString> &configFiles)
 {
     QString diagramType = Uml::DiagramType::toString(scene->type()).toLower();
-#if QT_VERSION >= 0x050000
-    const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QLatin1String("umbrello5/layouts"), QStandardPaths::LocateDirectory);
+    const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("umbrello5/layouts"), QStandardPaths::LocateDirectory);
     QStringList fileNames;
     foreach(const QString& dir, dirs) {
         const QStringList entries = QDir(dir).entryList(QStringList() << QString::fromLatin1("%1*.desktop").arg(diagramType));
@@ -315,19 +309,15 @@ bool LayoutGenerator::availableConfigFiles(UMLScene *scene, QHash<QString,QStrin
             fileNames.append(dir + QLatin1Char('/') + file);
         }
     }
-#else
-    KStandardDirs dirs;
-    QStringList fileNames = dirs.findAllResources("data", QString::fromLatin1("umbrello/layouts/%1*.desktop").arg(diagramType));
-#endif
     foreach(const QString &fileName, fileNames) {
         QFileInfo fi(fileName);
         QString baseName;
-        if (fi.baseName().contains(QLatin1String("-")))
+        if (fi.baseName().contains(QStringLiteral("-")))
             baseName = fi.baseName().remove(diagramType + QLatin1Char('-'));
         else if (fi.baseName() == diagramType)
             baseName = fi.baseName();
         else
-            baseName = QLatin1String("default");
+            baseName = QStringLiteral("default");
         KDesktopFile desktopFile(fileName);
         configFiles[baseName] = desktopFile.readName();
     }
@@ -395,15 +385,15 @@ bool LayoutGenerator::readGeneratedDotFile(const QString &fileName)
 bool LayoutGenerator::parseLine(const QString &line)
 {
     QStringList a = line.split(QLatin1Char(' '));
-    if (a[0] == QLatin1String("graph")) {
+    if (a[0] == QStringLiteral("graph")) {
         m_boundingRect = QRectF(0, 0, a[2].toDouble()*m_scale, a[3].toDouble()*m_scale);
         return true;
-    } else if (a[0] == QLatin1String("node")) {
+    } else if (a[0] == QStringLiteral("node")) {
         QString key = fixID(a[1]);
         m_nodes[key] = QRectF(a[2].toDouble()*m_scale, a[3].toDouble()*m_scale,
                               a[4].toDouble()*m_scale, a[5].toDouble()*m_scale);
         return true;
-    } else if (a[0] == QLatin1String("edge")) {
+    } else if (a[0] == QStringLiteral("edge")) {
         QString key = fixID(a[1]+a[2]);
         EdgePoints p;
         int len = a[3].toInt();
@@ -422,7 +412,7 @@ bool LayoutGenerator::parseLine(const QString &line)
         m_edgeLabelPosition[key] = QPointF(x*m_scale, y*m_scale);
 
         return true;
-    } else if (a[0] == QLatin1String("stop")) {
+    } else if (a[0] == QStringLiteral("stop")) {
         return true;
     }
     return false;
@@ -434,8 +424,8 @@ typedef QMap<QString,QStringList> ParameterList;
 bool LayoutGenerator::splitParameters(QMap<QString,QStringList> &map, const QString &s)
 {
     // FIXME: add shape=box without '"'
-    static QRegExp rx(QLatin1String("([a-zA-Z_]+)=\"([a-zA-Z0-9.- #]+)\""));
-    static QRegExp rx2(QLatin1String("([a-zA-Z_]+)=([a-zA-Z0-9.- #]+)"));
+    static QRegExp rx(QStringLiteral("([a-zA-Z_]+)=\"([a-zA-Z0-9.- #]+)\""));
+    static QRegExp rx2(QStringLiteral("([a-zA-Z_]+)=([a-zA-Z0-9.- #]+)"));
     int pos = 0;
     int count = 0;
     /*
@@ -460,13 +450,13 @@ bool LayoutGenerator::splitParameters(QMap<QString,QStringList> &map, const QStr
         //qDebug() << key << value;
 
         QStringList data;
-        if (key == QLatin1String("pos")) {
-            value.remove(QLatin1String("e,"));
+        if (key == QStringLiteral("pos")) {
+            value.remove(QStringLiteral("e,"));
             data = value.split(QLatin1Char(' '));
         } else if (key.startsWith(QLatin1Char('_'))) {
             data = value.split(QLatin1Char(' '));
         }
-        else if (key == QLatin1String("label"))
+        else if (key == QStringLiteral("label"))
             data = QStringList() << value;
         else
             data = value.split(QLatin1Char(','));
@@ -494,7 +484,7 @@ digraph G {
 
 bool LayoutGenerator::parseLine(const QString &line)
 {
-    static QRegExp m_cols(QLatin1String("^[\t ]*(.*)[\t ]*\\[(.*)\\]"));
+    static QRegExp m_cols(QStringLiteral("^[\t ]*(.*)[\t ]*\\[(.*)\\]"));
     static int m_level = -1;
 
     if (line.contains(QLatin1Char('{'))) {
@@ -516,27 +506,27 @@ bool LayoutGenerator::parseLine(const QString &line)
     splitParameters(attributes, attributeString);
     DEBUG() << attributes;
 
-    if (keyword == QLatin1String("graph")) {
-        if (attributes.contains(QLatin1String("bb"))) {
-            QStringList &a = attributes[QLatin1String("bb")];
+    if (keyword == QStringLiteral("graph")) {
+        if (attributes.contains(QStringLiteral("bb"))) {
+            QStringList &a = attributes[QStringLiteral("bb")];
             m_boundingRect.setLeft(a[0].toDouble());
             m_boundingRect.setTop(a[1].toDouble());
             m_boundingRect.setRight(a[2].toDouble());
             m_boundingRect.setBottom(a[3].toDouble());
         }
-    } else if (keyword == QLatin1String("node")) {
+    } else if (keyword == QStringLiteral("node")) {
         return true;
-    } else if (keyword == QLatin1String("edge")) {
+    } else if (keyword == QStringLiteral("edge")) {
         return true;
     // transition
-    } else if (line.contains(QLatin1String("->"))) {
+    } else if (line.contains(QStringLiteral("->"))) {
         QStringList k = keyword.split(QLatin1Char(' '));
         if (k.size() < 3)
             return false;
         QString key = fixID(k[0]+k[2]);
 
-        if (attributes.contains(QLatin1String("pos"))) {
-            QStringList &a = attributes[QLatin1String("pos")];
+        if (attributes.contains(QStringLiteral("pos"))) {
+            QStringList &a = attributes[QStringLiteral("pos")];
             EdgePoints points;
 
             for(int i = 1; i < a.size(); i++) {
@@ -550,9 +540,9 @@ bool LayoutGenerator::parseLine(const QString &line)
 
             m_edges[key] = points;
         }
-        if (0 && attributes.contains(QLatin1String("_draw_"))) {
-            QStringList &a = attributes[QLatin1String("_draw_")];
-            if (a.size() < 5 || (a[3] != QLatin1String("L") && a[3] != QLatin1String("p")))
+        if (0 && attributes.contains(QStringLiteral("_draw_"))) {
+            QStringList &a = attributes[QStringLiteral("_draw_")];
+            if (a.size() < 5 || (a[3] != QStringLiteral("L") && a[3] != QStringLiteral("p")))
                 return false;
             int size = a[4].toInt();
             EdgePoints points;
@@ -569,19 +559,19 @@ bool LayoutGenerator::parseLine(const QString &line)
         double scale = 72.0;
         QRectF f(0, 0, 0, 0);
         QString id = fixID(keyword);
-        if (attributes.contains(QLatin1String("pos"))) {
-            QStringList &a = attributes[QLatin1String("pos")];
+        if (attributes.contains(QStringLiteral("pos"))) {
+            QStringList &a = attributes[QStringLiteral("pos")];
             QStringList b = a[0].split(QLatin1Char(','));
             f.setLeft(b[0].toDouble());
             f.setTop(b[1].toDouble());
         }
-        if (attributes.contains(QLatin1String("height"))) {
-            QStringList &a = attributes[QLatin1String("height")];
+        if (attributes.contains(QStringLiteral("height"))) {
+            QStringList &a = attributes[QStringLiteral("height")];
             f.setHeight(a[0].toDouble()*scale);
         }
 
-        if (attributes.contains(QLatin1String("width"))) {
-            QStringList &a = attributes[QLatin1String("width")];
+        if (attributes.contains(QStringLiteral("width"))) {
+            QStringList &a = attributes[QStringLiteral("width")];
             f.setWidth(a[0].toDouble()*scale);
         }
         DEBUG() << "LayoutGenerator::parseLine adding " << id << f;
