@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2016-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2016-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 #include "diagramsmodel.h"
@@ -86,7 +86,7 @@ QVariant DiagramsModel::data(const QModelIndex & index, int role) const
         return v->umlScene()->folder()->name();
     else
         return QVariant(QString::number(v->umlScene()->widgetList().size())
-                        + QLatin1String("/")
+                        + QStringLiteral("/")
                         + QString::number(v->umlScene()->associationList().size()));
 }
 
@@ -135,12 +135,6 @@ void DiagramsModel::emitDataChanged(int index)
 
 void DiagramsModel::emitDataChanged(UMLView *view)
 {
-#if QT_VERSION < 0x050000
-    emit layoutAboutToBeChanged();
-#endif
     int index = m_views.indexOf(view);
     emitDataChanged(index);
-#if QT_VERSION < 0x050000
-    emit layoutChanged();
-#endif
 }
