@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2004-2021 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2004-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 // own header
@@ -29,6 +29,8 @@
 #include <KLocalizedString>
 #include <KMessageBox>
 
+DEBUG_REGISTER(ToolBarStateAssociation)
+
 /**
  * Creates a new ToolBarStateAssociation.
  *
@@ -114,10 +116,14 @@ void ToolBarStateAssociation::mouseReleaseAssociation()
         return;
     }
 
-    currentAssociation()->createAssocClassLine(
-            static_cast<ClassifierWidget*>(m_firstWidget),
-            currentAssociation()->associationLine()->closestSegmentIndex(m_pMouseEvent->scenePos()));
-    m_firstWidget->addAssoc(currentAssociation());
+    ClassifierWidget *classifier = dynamic_cast<ClassifierWidget*>(m_firstWidget);
+    if (classifier) {
+        currentAssociation()->createAssocClassLine(classifier,
+            currentAssociation()->associationLine().closestSegmentIndex(m_pMouseEvent->scenePos()));
+        m_firstWidget->addAssoc(currentAssociation());
+    } else {
+        logError0("ToolBarStateAssociation::mouseReleaseAssociation: dynamic_cast to ClassifierWidget* failed");
+    }
     cleanAssociation();
 }
 
@@ -250,7 +256,7 @@ void ToolBarStateAssociation::setSecondWidget()
             else if (type == Uml::AssociationType::Aggregation) {
                 UMLClassifier *c = widgetA->umlObject()->asUMLClassifier();
                 UMLAttribute *attr = new UMLAttribute(c, c->uniqChildName(UMLObject::ot_Attribute));
-                attr->setTypeName(QString(QLatin1String("%1*")).arg(widgetB->umlObject()->name()));
+                attr->setTypeName(QString(QStringLiteral("%1*")).arg(widgetB->umlObject()->name()));
                 c->addAttribute(attr);
                 cleanAssociation();
                 emit finished();
@@ -260,8 +266,9 @@ void ToolBarStateAssociation::setSecondWidget()
         AssociationWidget *temp = AssociationWidget::create(m_pUMLScene, widgetA, type, widgetB);
         if (widgetA->baseType() == UMLWidget::wt_Port) {
             QPointF lineStart = widgetA->getPos();
-            uDebug() << "ToolBarStateAssociation::setSecondWidget : lineStart = " << lineStart;
-            temp->associationLine()->setPoint(0, lineStart);
+            logDebug2("ToolBarStateAssociation::setSecondWidget : lineStart = (%1,%2)",
+                      lineStart.x(), lineStart.y());
+            temp->associationLine().setPoint(0, lineStart);
         }
         FloatingTextWidget *wt = temp->textWidgetByRole(Uml::TextRole::Coll_Message);
         if (wt)
@@ -302,8 +309,8 @@ Uml::AssociationType::Enum ToolBarStateAssociation::getAssociationType()
         case WorkToolBar::tbb_Seq_Combined_Fragment:
         case WorkToolBar::tbb_Seq_Precondition:
         case WorkToolBar::tbb_Seq_Message_Asynchronous: at = Uml::AssociationType::Seq_Message;       break;
-        case WorkToolBar::tbb_Coll_Mesg_Sync: at = Uml::AssociationType::Coll_Mesg_Sync;      break;
-        case WorkToolBar::tbb_Coll_Mesg_Async: at = Uml::AssociationType::Coll_Mesg_Async;      break;
+        case WorkToolBar::tbb_Coll_Mesg_Sync:           at = Uml::AssociationType::Coll_Mesg_Sync;    break;
+        case WorkToolBar::tbb_Coll_Mesg_Async:          at = Uml::AssociationType::Coll_Mesg_Async;   break;
         case WorkToolBar::tbb_State_Transition:         at = Uml::AssociationType::State;             break;
         case WorkToolBar::tbb_Activity_Transition:      at = Uml::AssociationType::Activity;          break;
         case WorkToolBar::tbb_Exception:                at = Uml::AssociationType::Exception;         break;
@@ -339,7 +346,7 @@ bool ToolBarStateAssociation::addAssociationInViewAndDoc(AssociationWidget* asso
         }
         return true;
     } else {
-        uError() << "cannot addAssocInViewAndDoc(), deleting";
+        logError0("ToolBarStateAssociation: cannot addAssocInViewAndDoc(), deleting");
         delete assoc;
         return false;
     }
