@@ -1,12 +1,7 @@
-/***************************************************************************
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   copyright (C) 2003-2014                                               *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
- ***************************************************************************/
+/*
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2003-2021 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+*/
 
 #ifndef ENUM_H
 #define ENUM_H
@@ -23,7 +18,7 @@ class UMLEnumLiteral;
  *
  * @short Non-graphical Information for an Enum.
  * @author Jonathan Riddell
- * Bugs and comments to umbrello-devel@kde.org or http://bugs.kde.org
+ * Bugs and comments to umbrello-devel@kde.org or https://bugs.kde.org
  */
 class UMLEnum : public UMLClassifier
 {
@@ -50,11 +45,11 @@ public:
 
     int removeEnumLiteral(UMLEnumLiteral* literal);
 
-    int enumLiterals();
+    int enumLiterals() const;
 
     void signalEnumLiteralRemoved(UMLClassifierListItem *elit);
 
-    virtual void saveToXMI(QDomDocument & qDoc, QDomElement & qElement);
+    virtual void saveToXMI(QXmlStreamWriter& writer);
 
     virtual UMLClassifierListItem* makeChildObject(const QString& xmiTag);
 
@@ -63,7 +58,7 @@ signals:
     void enumLiteralRemoved(UMLClassifierListItem*);
 
 protected:
-    bool load(QDomElement & element);
+    bool load1(QDomElement & element);
 
 private:
     void init();
