@@ -7,7 +7,7 @@
 #include "umlviewimageexporter.h"
 
 // application specific includes
-#define DBG_SRC QLatin1String("UMLViewImageExporter")
+#define DBG_SRC QStringLiteral("UMLViewImageExporter")
 #include "debug_utils.h"
 #include "dotgenerator.h"
 #include "umlfiledialog.h"
@@ -17,21 +17,13 @@
 #include "umlscene.h"
 
 //kde include files
-#if QT_VERSION >= 0x050000
 #include <KIO/Job>
 #include <KJobWidgets>
-#else
-#include <kfiledialog.h>
-#include <kurl.h>
-#include <kio/netaccess.h>
-#endif
 #include <KLocalizedString>
 #include <KMessageBox>
 
 // Qt include files
-#if QT_VERSION >= 0x050000
 #include <QFileDialog>
-#endif
 #include <QPointer>
 #include <QString>
 #include <QStringList>
@@ -107,21 +99,13 @@ bool UMLViewImageExporter::prepareExport()
         }
 
         // check if the file exists
-#if QT_VERSION >= 0x050000
         KIO::StatJob *job = KIO::stat(m_imageURL, KIO::StatJob::SourceSide, 0);
         KJobWidgets::setWindow(job, UMLApp::app());
         job->exec();
         bool result = !job->error();
-#else
-        bool result = KIO::NetAccess::exists(m_imageURL, KIO::NetAccess::SourceSide, UMLApp::app());
-#endif
         if (result) {
             int wantSave = KMessageBox::warningContinueCancel(0,
-#if QT_VERSION >= 0x050000
                                 i18n("The selected file %1 exists.\nDo you want to overwrite it?", m_imageURL.url(QUrl::PreferLocalFile)),
-#else
-                                i18n("The selected file %1 exists.\nDo you want to overwrite it?", m_imageURL.pathOrUrl()),
-#endif
                                 i18n("File Already Exists"), KGuiItem(i18n("&Overwrite")));
             if (wantSave == KMessageBox::Continue) {
                 exportPrepared = true;
@@ -146,11 +130,7 @@ bool UMLViewImageExporter::getParametersFromUser()
     bool success = true;
 
     // configure & show the file dialog
-#if QT_VERSION >= 0x050000
     QUrl url;
-#else
-    KUrl url;
-#endif
     QPointer<UMLFileDialog> dialog = new UMLFileDialog(url, QString(), UMLApp::app());
     prepareFileDialog(dialog);
     dialog->exec();
@@ -163,12 +143,8 @@ bool UMLViewImageExporter::getParametersFromUser()
 
         // update image url and mime type
         m_imageURL = dialog->selectedUrl();
-#if QT_VERSION >= 0x050000
         QFileInfo f(m_imageURL.toLocalFile());
         m_imageMimeType = UMLViewImageExporterModel::imageTypeToMimeType(f.suffix());
-#else
-        m_imageMimeType = dialog->currentMimeFilter();
-#endif
         UMLApp::app()->setImageMimeType(m_imageMimeType);
         logDebug2("UMLViewImageExporter::getParametersFromUser: image mime type=%1"
                   " / URL=%2", m_imageMimeType, m_imageURL.path());
@@ -190,32 +166,19 @@ void UMLViewImageExporter::prepareFileDialog(UMLFileDialog *fileDialog)
 
     QHash<QString, QString> configFiles;
     if (!DotGenerator::availableConfigFiles(m_scene, configFiles) || configFiles.size() == 0)
-        mimeTypes.removeOne(QLatin1String("image/x-dot"));
+        mimeTypes.removeOne(QStringLiteral("image/x-dot"));
 
     fileDialog->setCaption(i18n("Save As"));
-#if QT_VERSION >= 0x050000
     fileDialog->setAcceptMode(QFileDialog::AcceptSave);
     fileDialog->setMimeTypeFilters(mimeTypes);
-#else
-    fileDialog->setOperationMode(KFileDialog::Saving);
-    fileDialog->setMimeFilter(mimeTypes, m_imageMimeType);
-#endif
 
     // set a sensible default filename
     if (m_imageURL.isEmpty()) {
-#if QT_VERSION >= 0x050000
         QUrl docURL = UMLApp::app()->document()->url();
         docURL.setUrl(docURL.toString(QUrl::RemoveFilename)
                       + m_scene->name() + QLatin1Char('.')
                       + UMLViewImageExporterModel::mimeTypeToImageType(m_imageMimeType));
         fileDialog->selectUrl(docURL);
-#else
-        KUrl docURL = UMLApp::app()->document()->url();
-        KUrl directory = docURL;
-        directory.setPath(docURL.directory());
-
-        fileDialog->setUrl(directory);
-#endif
         fileDialog->setSelection(m_scene->name() + QLatin1Char('.') + UMLViewImageExporterModel::mimeTypeToImageType(m_imageMimeType));
     } else {
         fileDialog->setUrl(m_imageURL);
